==> nextcloud-25.0.12p1.tgz: nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Waiting…" : "Ootan...",
    "error" : "viga",
    "finished" : "lõpetatud",
    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "Terms of service" : "Kasutustingimused",
    "Show list view" : "Näita loendivaadet",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "You removed yourself" : "Sa eemaldasid iseenda",
    "{actor} removed themselves" : "{actor} eemaldas enda",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "Share expired" : "Jagamine aegus",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas sinuga {file}",
    "{actor} removed you from the share named {file}" : "{actor} lõpetas sinuga {file} jagamise",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "Files" : "Failid",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Shared link" : "Jagatud link",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Could not create share" : "Ei saanud jagamist luua",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "shared by %s" : "jagas %s",
    "Download all files" : "Lae kõik failid alla",
    "Direct link" : "Otsene link",
    "Share API is disabled" : "Jagamise API on keelatud",
    "File sharing" : "Faide jagamine",
    "Share will expire tomorrow" : "Jagamine aegub homme",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "Sharing" : "Jagamine",
    "Reset" : "Lähtesta",
    "Unknown error" : "Tundmatu viga",
    "Allow editing" : "Luba muutmine",
    "Read only" : "kirjutuskaitstud",
    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
    "Read" : "Lugemine",
    "Upload" : "Lae üles",
    "Edit" : "Redigeeri",
    "group" : "grupp",
    "conversation" : "vestlus",
    "remote" : "kaug",
    "remote group" : "Kauggrupp",
    "guest" : "külaline",
    "Unshare" : "Lõpeta jagamine",
    "Internal link" : "Sisemine link",
    "Cannot copy, please copy the link manually" : "Ei saa kopeerida, palun kopeeri link käsitsi",
    "Link copied" : "Link kopeeritud",
    "Password protection (enforced)" : "Paroolikaitse (jõustatud)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Expiration date (enforced)" : "Aegumise kuupäev (jõustatud)",
    "Enter a date" : "Sisesta kuupäev",
    "Cancel" : "Loobu",
    "Add another link" : "Lisa veel üks link",
    "Share link" : "Jaga link",
    "Can edit" : "Võib redigeerida",
    "No recommendations. Start typing." : "Soovitusi pole. Alusta trükkimist.",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Searching …" : "Otsin ...",
    "Guest" : "Külaline",
    "Group" : "Grupp",
    "Email" : "Epost",
    "Circle" : "Ring",
    "Advanced settings" : "Lisavalikud",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration date" : "Aegumise kuupäev",
    "Note to recipient" : "Märge saajale",
    "Create" : "Lisa",
    "Update" : "Uuenda",
    "Share" : "Jaga",
    "Expires {relativetime}" : "Aegub {relativetime}",
    "this share just expired." : "see jagamine aegus äsja",
    "Shared with you by {owner}" : "Jagatud sinuga {owner} poolt",
    "Shared" : "Jagatud",
    "Shared by" : "Jagas",
    "Shared with" : "Jagatud",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja grupiga {group} {owner} poolt",
    "Shares" : "Jagamisi",
    "No shares" : "Jagamisi pole",
    "Shared with you" : "Sinuga jagatud",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Shared with others" : "Teistega jagatud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Shared by link" : "Jagatud lingiga",
    "No shared links" : "Jagatud linke pole",
    "Deleted shares" : "Kustutatud jagamised",
    "No deleted shares" : "Kustutatud jagamisi pole",
    "Pending shares" : "Ootel jagamised",
    "No pending shares" : "Ootel jagamisi pole",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Share note" : "Jaga märget",
    "Upload files to %s" : "Laadi failid %s",
    "Note" : "Märge",
    "Select or drop files" : "Vali või lohista failid",
    "Uploaded files:" : "Üleslaetud failid:",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Shares you deleted will show up here" : "Sinu kustutatud jagamisi näidatakse siin",
    "Shares will show up here" : "Jagamisi näidatakse siin",
    "Restore" : "Taasta",
    "Something happened. Unable to restore the share." : "Midagi juhtus. Ei saa jagamist taastada.",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "One or more of your shares will expire tomorrow" : "Sinu üks või enam jagamist aegub homme",
    "Allow creating" : "Luba loomine",
    "Allow deleting" : "Luba kustutamine",
    "Allow resharing" : "Luba edasijagamine",
    "Expiration date enforced" : "Aegumise kuupäev jõustatud",
    "Password protect" : "Parooliga kaitsmine"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Waiting…" : "Ootan...",
    "error" : "viga",
    "finished" : "lõpetatud",
    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "Terms of service" : "Kasutustingimused",
    "Show list view" : "Näita loendivaadet",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "You removed yourself" : "Sa eemaldasid iseenda",
    "{actor} removed themselves" : "{actor} eemaldas enda",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "Share expired" : "Jagamine aegus",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas sinuga {file}",
    "{actor} removed you from the share named {file}" : "{actor} lõpetas sinuga {file} jagamise",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "Files" : "Failid",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Shared link" : "Jagatud link",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Could not create share" : "Ei saanud jagamist luua",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "shared by %s" : "jagas %s",
    "Download all files" : "Lae kõik failid alla",
    "Direct link" : "Otsene link",
    "Share API is disabled" : "Jagamise API on keelatud",
    "File sharing" : "Faide jagamine",
    "Share will expire tomorrow" : "Jagamine aegub homme",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "Sharing" : "Jagamine",
    "Reset" : "Lähtesta",
    "Unknown error" : "Tundmatu viga",
    "Allow editing" : "Luba muutmine",
    "Read only" : "kirjutuskaitstud",
    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
    "Read" : "Lugemine",
    "Upload" : "Lae üles",
    "Edit" : "Redigeeri",
    "group" : "grupp",
    "conversation" : "vestlus",
    "remote" : "kaug",
    "remote group" : "Kauggrupp",
    "guest" : "külaline",
    "Unshare" : "Lõpeta jagamine",
    "Internal link" : "Sisemine link",
    "Cannot copy, please copy the link manually" : "Ei saa kopeerida, palun kopeeri link käsitsi",
    "Link copied" : "Link kopeeritud",
    "Password protection (enforced)" : "Paroolikaitse (jõustatud)",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Expiration date (enforced)" : "Aegumise kuupäev (jõustatud)",
    "Enter a date" : "Sisesta kuupäev",
    "Cancel" : "Loobu",
    "Add another link" : "Lisa veel üks link",
    "Share link" : "Jaga link",
    "Can edit" : "Võib redigeerida",
    "No recommendations. Start typing." : "Soovitusi pole. Alusta trükkimist.",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Searching …" : "Otsin ...",
    "Guest" : "Külaline",
    "Group" : "Grupp",
    "Email" : "Epost",
    "Circle" : "Ring",
    "Advanced settings" : "Lisavalikud",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration date" : "Aegumise kuupäev",
    "Note to recipient" : "Märge saajale",
    "Create" : "Lisa",
    "Share" : "Jaga",
    "Expires {relativetime}" : "Aegub {relativetime}",
    "this share just expired." : "see jagamine aegus äsja",
    "Shared with you by {owner}" : "Jagatud sinuga {owner} poolt",
    "Shared" : "Jagatud",
    "Shared by" : "Jagas",
    "Shared with" : "Jagatud",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja grupiga {group} {owner} poolt",
    "Shares" : "Jagamisi",
    "No shares" : "Jagamisi pole",
    "Shared with you" : "Sinuga jagatud",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Shared with others" : "Teistega jagatud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Shared by link" : "Jagatud lingiga",
    "No shared links" : "Jagatud linke pole",
    "Deleted shares" : "Kustutatud jagamised",
    "No deleted shares" : "Kustutatud jagamisi pole",
    "Pending shares" : "Ootel jagamised",
    "No pending shares" : "Ootel jagamisi pole",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Share note" : "Jaga märget",
    "Upload files to %s" : "Laadi failid %s",
    "Note" : "Märge",
    "Select or drop files" : "Vali või lohista failid",
    "Uploaded files:" : "Üleslaetud failid:",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Shares you deleted will show up here" : "Sinu kustutatud jagamisi näidatakse siin",
    "Shares will show up here" : "Jagamisi näidatakse siin",
    "Restore" : "Taasta",
    "Something happened. Unable to restore the share." : "Midagi juhtus. Ei saa jagamist taastada.",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "Allow creating" : "Luba loomine",
    "Allow deleting" : "Luba kustutamine",
    "Allow resharing" : "Luba edasijagamine",
    "Expiration date enforced" : "Aegumise kuupäev jõustatud",
    "Password protect" : "Parooliga kaitsmine",
    "Update" : "Uuenda"
},
"nplurals=2; plural=(n != 1);");
